@@ -46,7 +46,8 @@ spacer2.writeConfig("length", "10")
 panel.addWidget("org.kde.plasma.pager")
 
 var taskmanager = panel.addWidget("org.kde.plasma.icontasks")
-var launcherlist = [ "preferred://browser", "applications:patchance.desktop", "applications:ardour.desktop", "applications:com.obsproject.Studio.desktop", "applications:org.kde.krita.desktop", "applications:gimp.desktop", "applications:org.kde.kdenlive.desktop", "applications:org.kde.digikam.desktop", "applications:org.darktable.darktable.desktop",  "applications:systemsettings.desktop" ]
+var launcherlist = [ "preferred://browser",
+                     "applications:systemsettings.desktop" ]
 taskmanager.writeConfig("launchers", launcherlist)
 
 /* Next up is determining whether to add the Input Method Panel
@@ -92,7 +93,9 @@ if (langIds.indexOf(languageId) != -1) {
     panel.addWidget("org.kde.plasma.kimpanel");
 }
 
-panel.addWidget("org.kde.plasma.systemtray")
+var systemtray = panel.addWidget("org.kde.plasma.systemtray")
+var systrayitems = ["org.kde.kdeconnect", "org.kde.plasma.clipboard", "org.kde.plasma.manage-inputmethod", "org.kde.plasma.keyboardlayout", "org.kde.plasma.bluetooth", "org.kde.plasma.cameraindicator", "org.kde.plasma.vault", "org.kde.kupapplet", "org.kde.plasma.keyboardindicator", "org.kde.plasma.mediacontroller", "org.kde.plasma.networkmanagement", "org.kde.plasma.weather", "org.kde.plasma.notifications", "org.kde.plasma.printmanager", "org.kde.plasma.battery", "org.kde.kscreen", "org.kde.plasma.volume", "org.kde.plasma.devicenotifier", "org.kde.plasma.brightness", "com.github.magillos.pipewiresettings"]
+systemtray.writeConfig("extraItems", systrayitems)
 panel.addWidget("org.kde.plasma.digitalclock")
 panel.addWidget("org.kde.plasma.minimizeall")
 
